pub struct ReconstructionCacheKey { /* private fields */ }Expand description
Stable cache key for one file reconstruction response.
Implementations
Sourceimpl ReconstructionCacheKey
impl ReconstructionCacheKey
Sourcepub fn latest(file_id: &str, repository_scope: Option<&RepositoryScope>) -> Self
pub fn latest(file_id: &str, repository_scope: Option<&RepositoryScope>) -> Self
Creates a cache key for the latest visible reconstruction of one file.
Sourcepub fn version(
file_id: &str,
content_hash: &str,
repository_scope: Option<&RepositoryScope>,
) -> Self
pub fn version( file_id: &str, content_hash: &str, repository_scope: Option<&RepositoryScope>, ) -> Self
Creates a cache key for one immutable file version.
Sourcepub fn content_hash(&self) -> Option<&str>
pub fn content_hash(&self) -> Option<&str>
Returns the optional immutable content hash.
Sourcepub const fn repository_scope(&self) -> Option<&RepositoryScopeCacheKey>
pub const fn repository_scope(&self) -> Option<&RepositoryScopeCacheKey>
Returns the optional repository scope.